    /*  {"plava/PStore", "nativeOpenStore", "(Ljava/lang/String;)Lplava/PStore;", (void*) plava_PStore_nativeOpenStore},
	{"plava/PStore", "nativeNewStore", "(Ljava/lang/String;)Lplava/PStore;", (void*) plava_PStore_nativeNewStore},*/
  {"plava/PStore", "stabiliseAll", "()V", (void*) plava_PStore_stabiliseAll},

      /*        {"plava/PStore", "nativeCloseStore", "()V", (void*) plava_PStore_nativeCloseStore},*/
  {"plava/PStore", "nativeGetRootObject", "()Lplava/PStore;", (void*) plava_PStore_nativeGetRootObject},
  {"plava/PStore", "nativeSetRootObject", "(Lplava/PStore;)V", (void*) plava_PStore_nativeSetRootObject},
    /*  {"plava/test/ug/LexAn", "openFile", "(Ljava/lang/String;)V", (void*) plava_test_ug_LexAn_openFile}, 
  {"plava/test/ug/LexAn", "closeFile", "()V", (void*) plava_test_ug_LexAn_closeFile}, 
  {"plava/test/ug/LexAn", "getString", "()Ljava/lang/String;", (void*) plava_test_ug_LexAn_getString}, 
    */
